function [N, l2, h1] = main(h)

    circle = @(x) dist_circ(x,[0 0],1);
    plane = @(x) -x(:,2);
    dist = @(x) max(plane(x), circle(x));

    bbox = [-1 0; 1 1];
    Mesh = init_Mesh(bbox, h, dist, @h_uniform, [-1 0; 0 0; 1 0], 0);

    Mesh.ElemFlag = ones(size(Mesh.Elements,1),1);
    Mesh = add_Edges(Mesh);
    Mesh = add_Edge2Elem(Mesh);
    Mesh = bdflags(Mesh);

    A = assemMat_LFE(Mesh, @STIMA_Lapl_LFE);
    L = zeros(size(Mesh.Coordinates,1),1);

    [U,FreeDofs] = assemDir_LFE(Mesh, -2, @dirichlet);
    L = L - A*U;

    U(FreeDofs) = A(FreeDofs,FreeDofs)\L(FreeDofs);

    l2 = L2Err_LFE(Mesh, U, P7O6(), @dirichlet);
    h1 = H1SErr_LFE(Mesh, U, P7O6(), @grad);
    N = size(Mesh.Coordinates,1);

    function out = dirichlet(x,varargin)
        [p,r] = cart2pol(x(:,1), x(:,2));
        out = sqrt(r) .* sin(p/2);
    end

    function out = grad(x,varargin)
        [p,r] = cart2pol(x(:,1), x(:,2));
        rhat = [cos(p), sin(p)];
        phat = [-sin(p), cos(p)];

        out = 0.5 * repmat(r.^(-1/2),1,2) .* (repmat(sin(p/2),1,2) .* rhat + repmat(cos(p/2),1,2) .* phat);
    end

end
