function [U,rate] = main1D(alpha,beta)
% Function for 1D finite element solver on graded meshes.

%   Copyright 2008 Christoph Winter
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
  
  % Initialize constants
  NREFS = 8;                                         % Number of refinement steps
  XL = 0;                                             % Left-hand side boundary
  XR = 1;                                             % Right-hand side boundary
  F_HANDLE = @(x)alpha*(1-alpha)*x.^(alpha-2);        % Right-hand side source term
  GD_HANDLE = @(x)x.^alpha;                           % Dirichlet boundary data
 % U_EX = @(x)x.^alpha;                               % Exact solution   
  DU_EX = @(x)alpha.*x.^(alpha-1); % Exact derivative of solution 
  
  % Loop over different values of alpha
  N = zeros(NREFS,1);
  H1_SError = zeros(NREFS,1);
     
    MESH_WIDTH = 1e-1;                                % Mesh resolution  
      
  % Compute discretization error on a series of meshes
    for i = 1:NREFS
      
          % Compute mesh
          MESH_WIDTH = MESH_WIDTH/2;
          Coordinates = transpose(XL:MESH_WIDTH:XR).^beta;
  
          % Compute stiffness matrix and load vector
          A = assemMat_P1_1D(Coordinates,@STIMA_Lapl_1D);
          L = assemLoad_P1_1D(Coordinates,gauleg(0,1,10),F_HANDLE);
    
          % Incorporate Dirichlet boundary data
          [U,FreeDofs] = assemDir_1D(Coordinates,[1 size(Coordinates,1)],GD_HANDLE);
          L = L - A*U;
    
          % Solve the linear system
          U(FreeDofs) = A(FreeDofs,FreeDofs)\L(FreeDofs);

          % Compute discretization error
          H1_SError(i) = H1SErr_P1_1D(Coordinates,U,gauleg(0,1,10),DU_EX);
          N(i) = length(Coordinates)-2;
     end


% plot rate
% figure;
% h = axes;

% loglog(N,H1_SError)
% hold on

% grid('on');
% set(h,'FontSize',14);
% xlabel('Dofs [log]');
% ylabel('Discretization error [log]');

%add_Slope(gca,'SouthWest',-1);

% Compute the rate of convergence
p = polyfit(log(N),log(H1_SError),1);
rate = -p(1);